<?php

namespace App\Helpers;

class ApiResponseHelper
{
    /**
     * Success response with data
     */
    public static function success($data = [], $message = 'Success', $statusCode = 200)
    {
        return response()->json([
            'status' => 'success',
            'message' => $message,
            'data' => $data
        ], $statusCode);
    }

    /**
     * Error response with a message
     */
    public static function error($message = 'Failed', $statusCode = 400, $errors = [])
    {
        return response()->json([
            'status' => 'error',
            'message' => $message,
            'errors' => $errors
        ], $statusCode);
    }

    /**
     * 404 Not Found response
     */
    public static function notFound($message = 'Resource not found')
    {
        return self::error($message, 404);
    }

    /**
     * 403 Forbidden response
     */
    public static function forbidden($message = 'Access denied')
    {
        return self::error($message, 403);
    }

    /**
     * 401 Unauthorized response
     */
    public static function unauthorized($message = 'Unauthorized access')
    {
        return self::error($message, 401);
    }

    /**
     * Validation Error response
     */
    public static function validationError($errors, $message = 'Validation failed')
    {
        return self::error($message, 422, $errors);
    }
}
