<?php

namespace App\Http\Controllers;

use App\Services\PropertyRoomService;
use App\Helpers\ApiResponseHelper;
use Illuminate\Support\Facades\Auth;

class RoomsController extends Controller
{
    protected $propertyRoomService;

    public function __construct(PropertyRoomService $propertyRoomService)
    {
        $this->propertyRoomService = $propertyRoomService;
    }

    /**
     * Get all room IDs for the authenticated user's property.
     *
     * @return \Illuminate\Http\JsonResponse
     */
    public function getRoomIds()
    {
        $user = Auth::user();

        if (!$user->property_id) {
            return ApiResponseHelper::error('User has no property associated.', 404);
        }

        $roomIds = $this->propertyRoomService->getRoomIdsByPropertyId($user->property_id);

        return ApiResponseHelper::success($roomIds, 'Room IDs fetched successfully.');
    }
}
