<?php

use App\Http\Controllers\AuthController;
use App\Http\Controllers\RatesController;
use App\Http\Controllers\RoomsController;
use App\Http\Controllers\SeasonsController;
use App\Http\Controllers\SpecialRatesController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;


Route::post('/register', [AuthController::class, 'register']);
Route::post('/login', [AuthController::class, 'login']);
Route::post('/logout', [AuthController::class, 'logout'])->middleware('auth:sanctum');




Route::prefix('rates')->group(function () {
    Route::get('/rates-by-property', [RatesController::class, 'getRatesByPropertyId']);  // Get all rates
    Route::post('/create', [RatesController::class, 'createRate']);   // Create a new rate
    Route::get('/{id}', [RatesController::class, 'getRateByRoomId']);         // Get a rate by Room ID
    Route::put('/update', [RatesController::class, 'updateRateById']);      // Update a rate
    Route::put('/update-rate-by-date', [RatesController::class, 'updateRateForDate']); //Update Rate By For Specific Date (Calendar View)
});

Route::prefix('seasons')->group(function () {
    // Route for creating a season
    Route::post('/create', [SeasonsController::class, 'createOrUpdateSeason']);

    // Route for setting seasonal rates
    Route::post('/create-rate', [SeasonsController::class, 'setSeasonalRates']);
});


Route::prefix('specials')->group(function () {
    Route::post('/create-rate', [SpecialRatesController::class, 'saveSpecialRate']);
    Route::get('/rates-by-property', [SpecialRatesController::class, 'getSpecialRatesByPropertyId']);  // Get all Special rates
    Route::delete('/{id}', [SpecialRatesController::class, 'deleteSpecialRate']);
});


Route::middleware('auth:sanctum')->group(function () {
    Route::get('/rooms', [RoomsController::class, 'getRoomIds']);
});
